@@ -9,12 +9,18 @@ import re
 from pathlib import Path
 from multiprocessing import Pool, cpu_count
 from itertools import product
-from typing import Union, Sequence, Optional
+from typing import Union, Sequence, Optional, List
 
-from jinja2 import Environment, PackageLoader
-
-from dungeonsheets import character as _char, exceptions, readers, latex, monsters
-from dungeonsheets.stats import mod_str
+from dungeonsheets import (
+    character as _char,
+    exceptions,
+    readers,
+    latex,
+    epub,
+    monsters,
+    forms,
+)
+from dungeonsheets.forms import mod_str
 from dungeonsheets.content_registry import find_content
 from dungeonsheets.fill_pdf_template import (
     create_character_pdf_template,
@@ -41,107 +47,89 @@ ORDINALS = {
     9: "9th",
 }
 
-jinja_env = Environment(
-    loader=PackageLoader("dungeonsheets", "forms"),
-    block_start_string="[%",
-    block_end_string="%]",
-    variable_start_string="[[",
-    variable_end_string="]]",
-)
-jinja_env.filters["rst_to_latex"] = latex.rst_to_latex
-jinja_env.filters["mod_str"] = mod_str
-
 
 PDFTK_CMD = "pdftk"
 
 
+jinja_env = forms.jinja_environment()
+jinja_env.filters["rst_to_latex"] = latex.rst_to_latex
+jinja_env.filters["rst_to_html"] = epub.rst_to_html
+jinja_env.filters["to_heading_id"] = epub.to_heading_id
+
+
 # Custom types
 File = Union[Path, str]
 
 
-def create_subclasses_tex(
-    character: Character,
-    use_dnd_decorations: bool = False,
-) -> str:
-    template = jinja_env.get_template("subclasses_template.tex")
-    return template.render(character=character, use_dnd_decorations=use_dnd_decorations)
+class CharacterRenderer():
+    def __init__(self, template_name: str):
+        self.template_name = template_name
+        
+    def __call__(self, character: Character, content_suffix: str = "tex", use_dnd_decorations: bool = False):
+        template = jinja_env.get_template(self.template_name.format(suffix=content_suffix))
+        return template.render(character=character,
+                               use_dnd_decorations=use_dnd_decorations, ordinals=ORDINALS)
+
+create_character_sheet_content = CharacterRenderer("character_sheet_template.{suffix}")
+create_subclasses_content = CharacterRenderer("subclasses_template.{suffix}")
+create_features_content = CharacterRenderer("features_template.{suffix}")
+create_magic_items_content = CharacterRenderer("magic_items_template.{suffix}")
+create_spellbook_content = CharacterRenderer("spellbook_template.{suffix}")
+create_infusions_content = CharacterRenderer("infusions_template.{suffix}")
+create_druid_shapes_content = CharacterRenderer("druid_shapes_template.{suffix}")
 
 
-def create_features_tex(
-    character: Character,
-    use_dnd_decorations: bool = False,
-) -> str:
-    template = jinja_env.get_template("features_template.tex")
-    return template.render(character=character, use_dnd_decorations=use_dnd_decorations)
-
-
-def create_magic_items_tex(
-    character: Character,
-    use_dnd_decorations: bool = False,
-) -> str:
-    template = jinja_env.get_template("magic_items_template.tex")
-    return template.render(character=character, use_dnd_decorations=use_dnd_decorations)
-
-
-def create_monsters_tex(
+def create_monsters_content(
     monsters: Sequence[Union[monsters.Monster, str]],
+    suffix: str,
     use_dnd_decorations: bool = False,
 ) -> str:
     # Convert strings to Monster objects
-    template = jinja_env.get_template("monsters_template.tex")
-    return template.render(monsters=monsters, use_dnd_decorations=use_dnd_decorations)
+    template = jinja_env.get_template(f"monsters_template.{suffix}")
+    spell_list = [spell for monster in monsters for spell in monster.spells]
+    return template.render(monsters=monsters,
+                           use_dnd_decorations=use_dnd_decorations, spell_list=spell_list)
 
 
-def create_party_summary_tex(
+def create_party_summary_content(
     party: Sequence[Entity],
     summary_rst: str,
+    suffix: str,
     use_dnd_decorations: bool = False,
 ) -> str:
     log.debug("Preparing summary table for party: %s", party)
-    template = jinja_env.get_template("party_summary_template.tex")
+    template = jinja_env.get_template(f"party_summary_template.{suffix}")
     return template.render(
         party=party, summary=summary_rst, use_dnd_decorations=use_dnd_decorations
     )
 
 
-def create_spellbook_tex(
-    character: Character,
+
+
+def create_random_tables_content(
+    conjure_animals: bool,
+    suffix: str,
     use_dnd_decorations: bool = False,
 ) -> str:
-    template = jinja_env.get_template("spellbook_template.tex")
+    template = jinja_env.get_template(f"random_tables_template.{suffix}")
     return template.render(
-        character=character, ordinals=ORDINALS, use_dnd_decorations=use_dnd_decorations
+        conjure_animals=conjure_animals, use_dnd_decorations=use_dnd_decorations
     )
 
 
-def create_infusions_tex(
-    character: Character,
-    use_dnd_decorations: bool = False,
-) -> str:
-    template = jinja_env.get_template("infusions_template.tex")
-    return template.render(character=character, use_dnd_decorations=use_dnd_decorations)
-
-
-def create_druid_shapes_tex(
-    character: Character,
-    use_dnd_decorations: bool = False,
-) -> str:
-    template = jinja_env.get_template("druid_shapes_template.tex")
-    return template.render(character=character, use_dnd_decorations=use_dnd_decorations)
-
-
-def create_random_tables_tex(
-        conjure_animals: bool,
-        use_dnd_decorations: bool = False,
-) -> str:
-    template = jinja_env.get_template("random_tables_template.tex")
-    return template.render(conjure_animals=conjure_animals,
-                           use_dnd_decorations=use_dnd_decorations)
+def create_extra_gm_content(rst: str, title: str, suffix: str, use_dnd_decorations: bool=False):
+    """Create content for arbitrary additional text provided in a GM sheet."""
+    template = jinja_env.get_template(f"extra_gm_content.{suffix}")
+    full_title = title.replace("_", " ").title()
+    return template.render(
+        rst=rst, title=full_title, use_dnd_decorations=use_dnd_decorations
+    )
 
 
 def make_sheet(
     sheet_file: File,
     flatten: bool = False,
+    output_format: str = "pdf",
     fancy_decorations: bool = False,
     debug: bool = False,
 ):
@@ -153,6 +141,8 @@ def make_sheet(
     flatten : bool, optional
       If true, the resulting PDF will look better and won't be
       fillable form.
+    output_format
+      Either "pdf" or "epub" to generate a PDF file or an EPUB file.
     fancy_decorations : bool, optional
       Use fancy page layout and decorations for extra sheets, namely
       the dnd style file: https://github.com/rpgtex/DND-5e-LaTeX-Template.
@@ -167,6 +157,7 @@ def make_sheet(
     if sheet_props.get("sheet_type", "") == "gm":
         ret = make_gm_sheet(
             gm_file=sheet_file,
+            output_format=output_format,
             fancy_decorations=fancy_decorations,
             debug=debug,
         )
@@ -174,14 +165,22 @@ def make_sheet(
         ret = make_character_sheet(
             char_file=sheet_file,
             flatten=flatten,
+            output_format=output_format,
             fancy_decorations=fancy_decorations,
             debug=debug,
         )
     return ret
 
 
+format_suffixes = {
+    "pdf": "tex",
+    "epub": "html",
+}
+
+
 def make_gm_sheet(
     gm_file: Union[str, Path],
+    output_format: str = "pdf",
     fancy_decorations: bool = False,
     debug: bool = False,
 ):
@@ -191,6 +190,8 @@ def make_gm_sheet(
     ----------
     gm_file
       The file with the gm_sheet definitions.
+    output_format
+      Either "pdf" or "epub" to generate a PDF file or an EPUB file.
     fancy_decorations
       Use fancy page layout and decorations for extra sheets, namely
       the dnd style file: https://github.com/rpgtex/DND-5e-LaTeX-Template.
@@ -202,11 +203,13 @@ def make_gm_sheet(
     gm_file = Path(gm_file)
     basename = gm_file.stem
     gm_props = readers.read_sheet_file(gm_file)
+    session_title = gm_props.pop("session_title", f"GM Notes: {basename}")
     # Create the intro tex
-    tex = [
-        jinja_env.get_template("preamble.tex").render(
+    content_suffix = format_suffixes[output_format]
+    content = [
+        jinja_env.get_template(f"preamble.{content_suffix}").render(
             use_dnd_decorations=fancy_decorations,
-            title=gm_props.pop("session_title", "GM Session Notes"),
+            title=session_title,
         )
     ]
     # Add the party stats table and session summary
@@ -218,13 +221,17 @@ def make_gm_sheet(
             char_file = gm_file.parent / char_file
         char_file = char_file.resolve()
         # Load the character file
+        log.debug(f"Loading party member: {char_file}")
         character_props = readers.read_sheet_file(char_file)
         member = _char.Character.load(character_props)
         party.append(member)
     summary = gm_props.pop("summary", "")
-    tex.append(
-        create_party_summary_tex(
-            party, summary_rst=summary, use_dnd_decorations=fancy_decorations
+    content.append(
+        create_party_summary_content(
+            party,
+            summary_rst=summary,
+            suffix=content_suffix,
+            use_dnd_decorations=fancy_decorations,
         )
     )
     # Add the monsters
@@ -236,7 +243,7 @@ def make_gm_sheet(
         else:
             try:
                 MyMonster = find_content(monster, valid_classes=[monsters.Monster])
-            except AttributeError:
+            except exceptions.ContentNotFound:
                 msg = f"Monster '{monster}' not found. Please add it to ``monsters.py``"
                 warnings.warn(msg)
                 continue
@@ -244,47 +251,164 @@ def make_gm_sheet(
                 new_monster = MyMonster()
         monsters_.append(new_monster)
     if len(monsters_) > 0:
-        tex.append(
-            create_monsters_tex(monsters_, use_dnd_decorations=fancy_decorations)
+        content.append(
+            create_monsters_content(
+                monsters_, suffix=content_suffix, use_dnd_decorations=fancy_decorations
+            )
         )
     # Add the random tables
-    random_tables = [s.replace(" ", "_").lower() for s in gm_props.pop("random_tables", [])]
-    tex.append(
-        create_random_tables_tex(
+    random_tables = [
+        s.replace(" ", "_").lower() for s in gm_props.pop("random_tables", [])
+    ]
+    content.append(
+        create_random_tables_content(
             conjure_animals=("conjure_animals" in random_tables),
+            suffix=content_suffix,
             use_dnd_decorations=fancy_decorations,
         )
     )
+    # Parse any extra homebrew attributes, etc.
+    gm_props.pop("dungeonsheets_version")
+    gm_props.pop("sheet_type")
+    extra_gm_attrs = []
+    for attr, text in gm_props.items():
+        if isinstance(text, str):
+            extra_gm_attrs.append(attr)
+            content.append(create_extra_gm_content(rst=text, title=attr, suffix=content_suffix, use_dnd_decorations=fancy_decorations))
+    for attr in extra_gm_attrs:
+        gm_props.pop(attr)
     # Add the closing TeX
-    tex.append(
-        jinja_env.get_template("postamble.tex").render(
+    content.append(
+        jinja_env.get_template(f"postamble.{format_suffixes[output_format]}").render(
             use_dnd_decorations=fancy_decorations
         )
     )
     # Warn about any unhandled sheet properties
-    gm_props.pop("dungeonsheets_version")
-    gm_props.pop("sheet_type")
     if len(gm_props.keys()) > 0:
         msg = f"Unhandled attributes in '{str(gm_file)}': {','.join(gm_props.keys())}"
-        log.warn(msg)
+        log.warning(msg)
         warnings.warn(msg)
-    # Typeset combined LaTeX file
-    try:
-        if len(tex) > 2:
-            latex.create_latex_pdf(
-                tex="".join(tex),
-                basename=basename,
-                keep_temp_files=debug,
-                use_dnd_decorations=fancy_decorations,
-            )
-    except exceptions.LatexNotFoundError:
-        log.warning(f"``pdflatex`` not available. Skipping {basename}")
+    # Produce the combined output depending on the format requested
+    if output_format == "pdf":
+        # Typeset combined LaTeX file
+        try:
+            if len(content) > 2:
+                latex.create_latex_pdf(
+                    tex="".join(content),
+                    basename=basename,
+                    keep_temp_files=debug,
+                    use_dnd_decorations=fancy_decorations,
+                )
+        except exceptions.LatexNotFoundError:
+            log.warning(f"``pdflatex`` not available. Skipping {basename}")
+    elif output_format == "epub":
+        chapters = {session_title: "".join(content)}
+        # Make sheets in the epub for each party member
+        for char in party:
+            char_html = make_character_content(char, "html",
+                                               fancy_decorations=fancy_decorations)
+            chapters[char.name] = "".join(char_html)
+        # Create the combined HTML file
+        epub.create_epub(
+            chapters=chapters,
+            basename=basename,
+            title=session_title,
+            use_dnd_decorations=fancy_decorations,
+        )
+    else:
+        raise exceptions.UnknownOutputFormat(
+            f"Unknown output format requested: {output_format}. Valid options are:"
+            " 'pdf', 'epub'"
+        )
+
+
+def make_character_content(
+        character: Character,
+        content_format: str,
+        fancy_decorations: bool = False,) -> List[str]:
+    """Prepare the inner content for a character sheet.
+
+    This will produce a fully renderable document, suitable for
+    passing to routines in either the ``epub`` or ``latex``
+    modules. If *content_format* is ``"html"``, the returned content
+    is just the portion that would be found inside the
+    ``<body></body>`` tag.
+
+    If *content_format* is ``"tex"``, the content returned will not
+    include the character, spell list, or biography sheets, since
+    these are currently processed through fillable PDFs.
+
+    Parameters
+    ----------
+    character
+      The character to render content for.
+    content_format
+      Which markup syntax to use, "tex" or "html".
+    fancy_decorations
+      Use fancy page layout and decorations for extra sheets, namely
+      the dnd style file for *tex*, or extended CSS for *html*.
+    
+    Returns
+    -------
+    content
+      The list of rendered character sheet contents for *character* in
+      markup format *content_format*.
+
+    """
+    # Preamble, empty for HTML
+    content = [
+        jinja_env.get_template(f"preamble.{content_format}").render(
+            use_dnd_decorations=fancy_decorations,
+            title="Features, Magical Items and Spells",
+        )
+    ]
+    # Make the character sheet, and background pages if producing HTML
+    if content_format != "tex":
+        content.append(create_character_sheet_content(character,
+                                                      content_suffix=content_format,
+                                                      use_dnd_decorations=fancy_decorations))
+    # Create a list of subcasses, features, spells, etc
+    if character.subclasses:
+        content.append(create_subclasses_content(character,
+                                                 content_suffix=content_format,
+                                                 use_dnd_decorations=fancy_decorations)
+                       )
+    if character.features:
+        content.append(
+            create_features_content(character, content_suffix=content_format, use_dnd_decorations=fancy_decorations)
+        )
+    if character.magic_items:
+        content.append(
+            create_magic_items_content(character, content_suffix=content_format, use_dnd_decorations=fancy_decorations)
+        )
+    if character.is_spellcaster:
+        content.append(
+            create_spellbook_content(character, content_suffix=content_format, use_dnd_decorations=fancy_decorations)
+        )
+    if len(getattr(character, "infusions", [])) > 0:
+        content.append(
+            create_infusions_content(character, content_suffix=content_format, use_dnd_decorations=fancy_decorations)
+        )
+
+    # Create a list of Druid wild_shapes
+    if len(getattr(character, "all_wild_shapes", [])) > 0:
+        content.append(
+            create_druid_shapes_content(character, content_suffix=content_format, use_dnd_decorations=fancy_decorations)
+        )
+    # Postamble, empty for HTML
+    content.append(
+        jinja_env.get_template(f"postamble.{content_format}").render(
+            use_dnd_decorations=fancy_decorations
+        )
+    )        
+    return content
 
 
 def make_character_sheet(
     char_file: Union[str, Path],
     character: Optional[Character] = None,
     flatten: bool = False,
+    output_format: str = "pdf",
     fancy_decorations: bool = False,
     debug: bool = False,
 ):
@@ -300,6 +424,8 @@ def make_character_sheet(
     flatten
       If true, the resulting PDF will look better and won't be
       fillable form.
+    output_format
+      Either "pdf" or "epub" to generate a PDF file or an EPUB file.
     fancy_decorations
       Use fancy page layout and decorations for extra sheets, namely
       the dnd style file: https://github.com/rpgtex/DND-5e-LaTeX-Template.
@@ -311,93 +437,68 @@ def make_character_sheet(
     if character is None:
         character_props = readers.read_sheet_file(char_file)
         character = _char.Character.load(character_props)
+    # Load image file if present
+    portrait_file=""
+    if character.portrait:
+        portrait_file=char_file.stem + ".jpeg"
     # Set the fields in the FDF
     basename = char_file.stem
     char_base = basename + "_char"
     person_base = basename + "_person"
     sheets = [char_base + ".pdf", person_base + ".pdf"]
     pages = []
-    tex = [
-        jinja_env.get_template("preamble.tex").render(
-            use_dnd_decorations=fancy_decorations,
-            title="Features, Magical Items and Spells",
-        )
-    ]
-
-    # Start of PDF gen
-    char_pdf = create_character_pdf_template(
-        character=character, basename=char_base, flatten=flatten
-    )
-    pages.append(char_pdf)
-    person_pdf = create_personality_pdf_template(
-        character=character, basename=person_base, flatten=flatten
-    )
-    pages.append(person_pdf)
-    if character.is_spellcaster:
-        # Create spell sheet
-        spell_base = "{:s}_spells".format(basename)
-        create_spells_pdf_template(
-            character=character, basename=spell_base, flatten=flatten
-        )
-        sheets.append(spell_base + ".pdf")
-    # end of PDF gen
-    features_base = "{:s}_features".format(basename)
-    # Create a list of subcasses
-    if character.subclasses:
-        tex.append(
-            create_subclasses_tex(character, use_dnd_decorations=fancy_decorations)
-        )
-
-    # Create a list of features
-    if character.features:
-        tex.append(
-            create_features_tex(character, use_dnd_decorations=fancy_decorations)
-        )
-
-    if character.magic_items:
-        tex.append(
-            create_magic_items_tex(character, use_dnd_decorations=fancy_decorations)
-        )
-
-    # Create a list of spells
-    if character.is_spellcaster:
-        tex.append(
-            create_spellbook_tex(character, use_dnd_decorations=fancy_decorations)
-        )
-
-    # Create a list of Artificer infusions
-    if getattr(character, "infusions", []):
-        tex.append(
-            create_infusions_tex(character, use_dnd_decorations=fancy_decorations)
-        )
-
-    # Create a list of Druid wild_shapes
-    if getattr(character, "wild_shapes", []):
-        tex.append(
-            create_druid_shapes_tex(character, use_dnd_decorations=fancy_decorations)
-        )
-
-    tex.append(
-        jinja_env.get_template("postamble.tex").render(
-            use_dnd_decorations=fancy_decorations
-        )
-    )
-
+    # Prepare the tex/html content
+    content_suffix = format_suffixes[output_format]
+    # Create a list of features and magic items
+    content = make_character_content(character=character,
+                                     content_format=content_suffix,
+                                     fancy_decorations=fancy_decorations)
     # Typeset combined LaTeX file
-    try:
-        if len(tex) > 2:
-            latex.create_latex_pdf(
-                tex="".join(tex),
-                basename=features_base,
-                keep_temp_files=debug,
-                use_dnd_decorations=fancy_decorations,
+    if output_format == "pdf":
+        # Fillable PDF forms
+        char_pdf = create_character_pdf_template(
+            character=character, basename=char_base, flatten=flatten
+        )
+        pages.append(char_pdf)
+        person_pdf = create_personality_pdf_template(
+            character=character, basename=person_base, portrait_file=portrait_file, flatten=flatten
+        )
+        pages.append(person_pdf)
+        if character.is_spellcaster:
+            # Create spell sheet
+            spell_base = "{:s}_spells".format(basename)
+            create_spells_pdf_template(
+                character=character, basename=spell_base, flatten=flatten
             )
-            sheets.append(features_base + ".pdf")
-            final_pdf = f"{basename}.pdf"
-            merge_pdfs(sheets, final_pdf, clean_up=True)
-    except exceptions.LatexNotFoundError:
-        log.warning(
-            f"``pdflatex`` not available. Skipping features for {character.name}"
+            sheets.append(spell_base + ".pdf")
+        # Combined with additional LaTeX pages with detailed character info
+        features_base = "{:s}_features".format(basename)
+        try:
+            if len(content) > 2:
+                latex.create_latex_pdf(
+                    tex="".join(content),
+                    basename=features_base,
+                    keep_temp_files=debug,
+                    use_dnd_decorations=fancy_decorations,
+                )
+                sheets.append(features_base + ".pdf")
+                final_pdf = f"{basename}.pdf"
+                merge_pdfs(sheets, final_pdf, clean_up=True)
+        except exceptions.LatexNotFoundError:
+            log.warning(
+                f"``pdflatex`` not available. Skipping features for {character.name}"
+            )
+    elif output_format == "epub":
+        epub.create_epub(
+            chapters={character.name: "".join(content)},
+            basename=basename,
+            title=character.name,
+            use_dnd_decorations=fancy_decorations,
+        )            
+    else:
+        raise exceptions.UnknownOutputFormat(
+            f"Unknown output format requested: {output_format}. Valid options are:"
+            " 'pdf', 'epub'"
         )
 
 
@@ -435,6 +536,7 @@ def _build(filename, args) -> int:
         make_sheet(
             sheet_file=filename,
             flatten=(not args.editable),
+            output_format=args.output_format,
             debug=args.debug,
             fancy_decorations=args.fancy_decorations,
         )
@@ -484,6 +586,13 @@ def main(args=None):
             "(experimental, requires https://github.com/rpgtex/DND-5e-LaTeX-Template)"
         ),
     )
+    parser.add_argument(
+        "--output-format",
+        "-o",
+        help="Specify the output format for the sheets.",
+        choices=["pdf", "epub"],
+        default="pdf",
+    )
     parser.add_argument(
         "--debug",
         "-d",
@@ -529,7 +638,7 @@ def main(args=None):
     # Process the requested files
     if args.debug:
         for filename in filenames:
-            print("building")
+            log.debug("building")
             _build(filename, args)
     else:
         with Pool(cpu_count()) as p:
